@@ -150,7 +150,7 @@ ffmpeg_renderer <- function(format = 'auto', ffmpeg = NULL, options = list(pix_f
   if (!has_ffmpeg(ffmpeg)) stop('The ffmpeg library is not available at the specified location', call. = FALSE)
   if (format == 'auto') {
     format <- if (.Platform$GUI == "RStudio" &&
-                  any(grepl('--enable-libvpx', system2('ffmpeg', '-version', stdout = TRUE)))) {
+                  any(grepl('--enable-libvpx', system2(ffmpeg, '-version', stdout = TRUE)))) {
       "webm"
     } else {
       "mp4"
@@ -238,6 +238,9 @@ sprite_renderer <- function() {
 #'
 #' @param file The gif file to be wrapped
 #' @param x A `gif_image` object
+#' @param f a ‘factor’ in the sense that [as.factor(f)][base::factor] defines
+#' the grouping, or a list of such factors in which case their interaction is
+#' used for the grouping.
 #' @inheritParams base::split
 #' @param ... Arguments passed on
 #'
@@ -328,7 +331,13 @@ print.video_file <- function(x, width = NULL, ...) {
 #' @export
 knit_print.video_file <- function(x, options, ...) {
   if (grepl('\\.(mp4)|(webm)|(ogg)$', x, ignore.case = TRUE)) {
-    knitr::knit_print(htmltools::browsable(as_html_video(x, width = get_chunk_width(options))), options, ...)
+    knitr::knit_print(
+      htmltools::browsable(
+        as_html_video(x, width = get_chunk_width(options), autoplay = get_chunk_autoplay(options))
+      ),
+      options,
+      ...
+    )
   } else {
     warning('The video format doesn\'t support HTML', call. = FALSE)
     invisible(NULL)
@@ -338,7 +347,7 @@ knit_print.video_file <- function(x, options, ...) {
 split.video_file <- function(x, f, drop = FALSE, ...) {
   stop('video_file objects does not support splitting', call. = FALSE)
 }
-as_html_video <- function(x, width = NULL) {
+as_html_video <- function(x, width = NULL, autoplay = TRUE) {
   if (!requireNamespace("base64enc", quietly = TRUE)) {
     stop('The base64enc package is required for showing video')
   }
@@ -347,15 +356,15 @@ as_html_video <- function(x, width = NULL) {
   }
   format <- tolower(sub('^.*\\.(.+)$', '\\1', x))
   htmltools::HTML(paste0(
-    '<video controls autoplay',
+    '<video controls', if (autoplay) ' autoplay' else '',
     if (is.null(width)) '' else paste0(' width="', width, '"'),
-    '><source src="data:video/',
-    format,
-    ';base64,',
-    base64enc::base64encode(x),
-    '" type="video/mp4"></video>'
+    '>',
+    '<source src="data:video/', format, ';base64,', base64enc::base64encode(x), '" type="video/mp4"></video>'
   ))
 }
+get_chunk_autoplay <- function(options) {
+  options$gganimate.autoplay %||% TRUE
+}
 #' Wrap an image sprite for easy handling
 #'
 #' This function is equivalent to [gif_file()] but works for animations encoded
